﻿using System;
using System.Collections.ObjectModel;
using System.Web.UI;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace ShowChildPopupSample
{
    public partial class Default : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
                Map1.CurrentExtent = new RectangleShape(-125, 72, 50, -46);
                Map1.MapUnit = GeographyUnit.DecimalDegree;

                WorldMapKitWmsWebOverlay worldMapKitOverlay = new WorldMapKitWmsWebOverlay();
                Map1.CustomOverlays.Add(worldMapKitOverlay);

                ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(MapPath("~/SampleData/cntry02.shp"));
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Transparent, GeoColor.FromArgb(100, GeoColor.SimpleColors.Green));
                worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                LayerOverlay staticOverlay = new LayerOverlay();
                staticOverlay.IsBaseOverlay = false;
                staticOverlay.Layers.Add("worldLayer", worldLayer);
                Map1.CustomOverlays.Add(staticOverlay);
            }
        }

        protected void Map1_Click(object sender, MapClickedEventArgs e)
        {
            FeatureLayer worldLayer = (ShapeFileFeatureLayer)((LayerOverlay)Map1.CustomOverlays[1]).Layers["worldLayer"];

            // Find the country the user clicked on.
            worldLayer.Open();
            Collection<Feature> selectedFeatures = worldLayer.QueryTools.GetFeaturesContaining(e.Position, new string[1] { "CNTRY_NAME" });
            worldLayer.Close();

            CloudPopup popup;
            if (Map1.Popups.Count == 0)
            {
                popup = new CloudPopup("Popup", e.Position, string.Empty);
                popup.AutoSize = true;
                Map1.Popups.Add(popup);

                CloudPopup childPopup = new CloudPopup("ChildPopup", e.Position, string.Empty);
                childPopup.AutoSize = true;
                childPopup.IsVisible = false;
                Map1.Popups.Add(childPopup);
            }
            else
            {
                popup = (CloudPopup)Map1.Popups["Popup"];
                popup.Position = e.Position;
            }

            // Determine the area of the country.
            if (selectedFeatures.Count > 0)
            {
                AreaBaseShape areaShape = (AreaBaseShape)selectedFeatures[0].GetShape();
                double area = areaShape.GetArea(GeographyUnit.DecimalDegree, AreaUnit.SquareKilometers);
                popup.ContentHtml = string.Format(@"<div style='color:#0065ce;font-size:10px; font-family:verdana; padding:4px;' onclick='javascript:showChildPopup(event);'><span style='color:red'>{0}</span> has an area of <span style='color:red'>{1:N0}</span> square kilometers.</div>", selectedFeatures[0].ColumnValues["CNTRY_NAME"], area);
                var childPopup = (CloudPopup)Map1.Popups["ChildPopup"];
                childPopup.ContentHtml = "Here is child popup";
            }
            else
            {
                popup.ContentHtml = @"<div style='color:#0065ce;font-size:10px; font-family:verdana; padding:4px;'>Please click on a country to see how large it is.</div>";
            }
        }
    }
}